# seaborn-image: image data visualization

[![Tests](https://github.com/SarthakJariwala/seaborn-image/workflows/Tests/badge.svg)](https://github.com/SarthakJariwala/seaborn-image/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/SarthakJariwala/seaborn-image/branch/master/graph/badge.svg)](https://codecov.io/gh/SarthakJariwala/seaborn-image)
[![PyPI](https://img.shields.io/pypi/v/seaborn-image.svg)](https://pypi.org/project/seaborn-image/)
[![Documentation Status](https://readthedocs.org/projects/seaborn-image/badge/?version=latest)](https://seaborn-image.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


<div class="row">

  <a href="https://seaborn-image.readthedocs.io/en/latest/auto_examples/plot_image_hist.html">
  <img src="./images/sphx_glr_plot_image_hist_001.png" height="120" width="170">
  </a>

  <a href="https://seaborn-image.readthedocs.io/en/latest/auto_examples/plot_filter.html">
  <img src="./images/sphx_glr_plot_filter_001.png" height="120" width="130">
  </a>

  <a href="https://seaborn-image.readthedocs.io/en/latest/auto_examples/plot_fft.html">
  <img src="./images/sphx_glr_plot_fft_001.png" height="120" width="120">
  </a>

  <a href="https://seaborn-image.readthedocs.io/en/latest/auto_examples/plot_filtergrid.html">
  <img src="./images/sphx_glr_plot_filtergrid_001.png" height="120" width="120">
  </a>

  <a href="https://seaborn-image.readthedocs.io/en/latest/auto_examples/plot_image_robust.html">
  <img src="./images/sphx_glr_plot_image_robust_001.png" height="120" width="260">
  </a>

</div>


## Description

Seaborn-image is a Python **image** visualization library based on matplotlib
and provides a high-level API to **draw attractive and informative images quickly and effectively**.

It is heavily inspired by [seaborn](https://seaborn.pydata.org/), a high-level visualization library
for drawing attractive statistical graphics in Python.

## Documentation

Detailed documentation can be found [here](https://seaborn-image.readthedocs.io/).

- [Tutorial](https://seaborn-image.readthedocs.io/en/latest/tutorial.html)
- [Examples](https://seaborn-image.sarthakjariwala.com/en/latest/auto_examples/index.html)
- [API Reference](https://seaborn-image.readthedocs.io/en/latest/reference.html)

## Installation

For latest release:

Using `pip`

```bash
pip install -U seaborn-image
```

Using `conda`

```bash
conda install seaborn-image -c conda-forge
```

For latest commit
```bash
pip install git+https://github.com/SarthakJariwala/seaborn-image
```

## Contributing

Please see the [contributing guidelines](https://github.com/SarthakJariwala/seaborn-image/blob/master/CONTRIBUTING.rst)
